==> landers.angular-1.0.6.tgz: package/inputs.js <==
angular.module('Landers.inputs', [])
    .directive('landersAttachment', function($compile, Flat, Dialog, List) {
        return {
            restrict : 'A',
            link : function($scope, $element, $attrs){
                var model_key = $attrs['attachModel'];
                var view_key = $attrs['attachView'];

                var html = '';
                html += '<div class="relative">';
                html += '   <a ng-click="landersAttachmentAdd($event)" class="btn btn-sm btn-primary absolute right-top">添加</a>';
                html += '</div>';
                html += '<input ng-model="' + model_key + '" type="hidden"/>';
                html += '<ul class="hlist list">';
                html += '    <li ng-repeat="item in ' + view_key + '" class="mr20 list-item">';
                html += '        <a href="{{item.url}}" target="_blank">{{item.title}}</a>';
                html += '        <a ng-click="landersAttachmentRemove($event)" class="ml5 btn btn-warning btn-sm">移除</a>';
                html += '    </li>';
                html += '</ul>';
                var el = $compile(html)($scope);
                $element.css({height:'100%'}).append(el);
                if (!$scope.$$phase) $scope.$apply();
                $element.find('.list').css({'margin-right':$element.find('.btn').width() + 20 })

                var lister = List.make($scope, view_key).data([]);
                $scope.$watch(model_key, function(model){
                    if (model) lister.data(model);
                });
                var html = '';
                html += '<form>';
                html += '<input type="hidden" id="url" ng-model="$runtime.attachment.url"/>';
                html += '<table cellpadding="0" cellspacing="0" border="0" class="stereo form-table" style="width:520px; height:220px;">';
                html += '    <tr><td class="w60">标题：</td>';
                html += '        <td><input type="text" class="text" ng-model="$runtime.attachment.title"/></td>';
                html += '    </tr>';
                html += '    <tr height="192"><td class="w60">上传：</td>';
                html += '        <td>';
                html += '            <div landers-upload class="upload text-center fl" rel="url" uploadid="7b2aa8e6ba1d06fae48d72ae28dc7469" tipid="upload_attachment_tip" pvw="180" pvh="180"></div>';
                html += '            <ul id="upload_attachment_tip" class="fl lh22"></ul>';
                html += '        </td>';
                html += '    </tr>';
                html += '</table>';
                html += '</form>';
                angular.extend($scope, {
                    landersAttachmentAdd : function(){
                        Flat.set($scope, '$runtime.attachment', {});
                        setTimeout(function(){
                            Dialog.show($scope, {
                                title   : '新增附件',
                                content : html,
                                top : '30%',
                                width   : 350,
                                lock    : true,
                                fixed   : true,
                                effect  : 'vmove2',
                                onload  : function(){
                                },
                                yes     : function(){
                                    var attach = Flat.get($scope, '$runtime.attachment');
                                    lister.append(angular.extend({}, attach));
                                    Flat.set($scope, model_key, angular.toJson(lister.data()));
                                },
                                no      : true
                            });
                        }, 200);
                    },
                    landersAttachmentRemove : function($event){
                        if (!confirm('确定要删除此附件？')) return;
                        lister.item.remove($event);
                        Flat.set($scope, model_key, angular.toJson(lister.data()));
                    }
                })
            }
        }
    })
    .directive('landersNameValueInputer', function($compile, Flat, Dialog, List) {
        return {
            restrict : 'A',
            link : function($scope, $element, $attrs){
                var model_key = $attrs['nviModel'];
                var view_key = $attrs['nviView'];

                var html = '';
                html += '<div class="relative">';
                html += '   <a ng-click="landersNameValuesAdd($event)" class="btn btn-sm btn-primary absolute right-top">添加</a>';
                html += '</div>';
                html += '<ul class="hlist list">';
                html += '    <li ng-repeat="item in ' + view_key + '" class="mr20 mb5 list-item">';
                html += '        <span class="">{{item.name}}：{{item.value}}</span>';
                html += '        <a ng-click="landersNameValuesRemove($event)" class="btn btn-warning btn-sm ml5">移除</a>';
                html += '    </li>';
                html += '</ul>';
                html += '<input ng-model="' + model_key + '" type="hidden"/>';

                var el = $compile(html)($scope);
                $element.css({height:'100%'}).append(el);
                if (!$scope.$$phase) $scope.$apply();
                $element.find('.list').css({'margin-right':$element.find('.btn').width() + 20 })

                var lister = List.make($scope, view_key).data([]);
                $scope.$watch(model_key, function(model){
                    if (model) lister.data(model);
                });

                var html = '';
                html += '<form>';
                html += '   <table cellpadding="0" cellspacing="0" border="0" class="stereo form-table">';
                html += '   <tr>';
                html += '       <td class="w60"><label>名称</label></td>';
                html += '       <td><input ng-model="$runtime.nvi.name" maxlength="30" value="" type="text" class="text"/></td>';
                html += '   </tr>';
                html += '   <tr>';
                html += '       <td class="w60"><label>数据</label></td>';
                html += '       <td><textarea ng-model="$runtime.nvi.value" value="" type="text" class="text"></textarea></td>';
                html += '   </tr>';
                html += '   </table>';
                html += '</form>';
                angular.extend($scope, {
                    landersNameValuesAdd : function(){
                        Flat.set($scope, '$runtime.nvi', {});
                        setTimeout(function(){
                            Dialog.show($scope, {
                                title   : $attrs['nviName'],
                                content : html,
                                width   : 350,
                                lock    : true,
                                fixed   : true,
                                effect  : 'vmove1',
                                onload  : function(){
                                },
                                yes     : function(){
                                    var nvi = Flat.get($scope, '$runtime.nvi');
                                    lister.append(angular.extend({}, nvi));
                                    Flat.set($scope, model_key, angular.toJson(lister.data()));
                                },
                                no      : true
                            });
                        }, 200);
                    },
                    landersNameValuesRemove : function($event){
                        lister.item.remove($event);
                        Flat.set($scope, model_key, angular.toJson(lister.data()));
                    }
                })
            }
        }
    })
    .directive('landersUpload', function($rootScope, Flat) {
        return {
            restrict : 'A',
            link : function($scope, $element, $attrs) {
                Landers.loader.jsm(['landers.iframe', 'landers.upload,true'], function(){
                    var $form = $element.closest('form');
                    var rel = $element.attr('rel');
                    var $rel = $form.find('#' + rel);
                    var relModel = $rel.attr('ng-model');
                    $rel.val(Flat.get($scope, relModel) || '');

                    var relsmall = $element.attr('rel_small');
                    if (relsmall) {
                        var $relsmall = $form.find('#' + relsmall);
                        var relsmallModel = $relsmall.attr('ng-model');
                        $relsmall.val(Flat.get($scope, relsmallModel) || '');
                    }
                    var tipid = $element.attr('tipid');
                    var $tip = $form.find('#' + tipid);
                    var params = $element.attr('params');
                    if (params) params = angular.fromJson(params); else params = {};
                    $scope.$watch(
                        function(){return $rel.val()},
                        function(newValue){
                            Flat.set($scope, relModel, newValue);
                        }
                    );
                    if (relsmall && $relsmall.length && relsmallModel) {
                        $scope.$watch(
                            function(){return $relsmall.val()},
                            function(newValue){
                                Flat.set($scope, relsmallModel, newValue);
                            }
                        );
                    };
                    var opts = {scope:$scope};
                    if (relsmall && $relsmall.length) opts.$small = $relsmall;
                    if ($tip.length)  opts.$tip = $tip;
                    opts.faces = $element.attr('faces') || 0;

                    var pvw = $element.attr('pvw'), pvh = $element.attr('pvh');
                    if (pvw || pvh) {
                        opts.pvsize = {};
                        if (pvw) opts.pvsize.width = pvw;
                        if (pvh) opts.pvsize.height = pvh;
                    };
                    opts.onload = function(){
                        var upload = this;
                        if (params.init_logo) {
                            var $faces = upload.getfaces();
                            $faces.each(function(){
                                Upload.plug.attach_setlogo($(this), params.init_logo, 'val_small');
                            });
                        };
                    };
                    opts.onchange = function(){
                        if (!$scope.$$phase) $scope.$apply();
                    };
                    opts = $.extend({}, opts, params);
                    opts.hosturl = $rootScope.$settings.env.upload_host_url;
                    opts.debug = !!params.debug;
                    Landers.upload.create(
                        $element.attr('uploadid'),
                        params.apiurl || 'upload.php', $element, $rel, opts
                    );
                });
            }
        };
    })

==> landers.angular-1.0.25.tgz: package/inputs.js <==
angular.module('Landers.inputs', [])
    .directive('landersAttachment', function($compile, Flat, Dialog, List) {
        return {
            restrict : 'A',
            link : function($scope, $element, $attrs){
                var model_key = $attrs['attachModel'];
                var view_key = $attrs['attachView'];

                var html = '';
                html += '<div class="relative">';
                html += '   <a ng-click="landersAttachmentAdd($event)" class="btn btn-sm btn-primary absolute right-top"><i class="glyphicon glyphicon-plus"></i></a>';
                html += '</div>';
                html += '<input ng-model="' + model_key + '" type="hidden"/>';
                html += '<ul class="hlist list">';
                html += '    <li ng-repeat="item in ' + view_key + '" class="mr20 list-item">';
                html += '        <a href="{{item.url}}" target="_blank">{{item.title}}</a>';
                html += '        <a ng-click="landersAttachmentRemove($event)" class="ml5 btn btn-warning btn-xs"><i class="glyphicon glyphicon-minus"></i></a>';
                html += '    </li>';
                html += '</ul>';
                var el = $compile(html)($scope);
                $element.css({height:'100%'}).append(el);
                if (!$scope.$$phase) $scope.$apply();
                $element.find('.list').css({'margin-right':$element.find('.btn').width() + 20 })

                var lister = List.make($scope, view_key).data([]);
                $scope.$watch(model_key, function(model){
                    if (model) lister.data(model);
                });
                var html = '';
                html += '<form>';
                html += '<input type="hidden" id="url" ng-model="$runtime.attachment.url"/>';
                html += '<table cellpadding="0" cellspacing="0" border="0" class="stereo form-table" style="width:520px; height:220px;">';
                html += '    <tr><td class="w60">标题：</td>';
                html += '        <td><input type="text" class="text" ng-model="$runtime.attachment.title"/></td>';
                html += '    </tr>';
                html += '    <tr height="192"><td class="w60">上传：</td>';
                html += '        <td>';
                html += '            <div landers-upload class="upload text-center fl" rel="url" uploadid="7b2aa8e6ba1d06fae48d72ae28dc7469" tipid="upload_attachment_tip" pvw="180" pvh="180"></div>';
                html += '            <ul id="upload_attachment_tip" class="fl lh22"></ul>';
                html += '        </td>';
                html += '    </tr>';
                html += '</table>';
                html += '</form>';
                angular.extend($scope, {
                    landersAttachmentAdd : function(){
                        Flat.set($scope, '$runtime.attachment', {});
                        setTimeout(function(){
                            Dialog.show($scope, {
                                title   : '新增附件',
                                content : html,
                                top : '30%',
                                width   : 350,
                                lock    : true,
                                fixed   : true,
                                effect  : 'vmove2',
                                onload  : function(){
                                },
                                yes     : function(){
                                    var attach = Flat.get($scope, '$runtime.attachment');
                                    lister.append(angular.extend({}, attach));
                                    Flat.set($scope, model_key, angular.toJson(lister.data()));
                                },
                                no      : true
                            });
                        }, 200);
                    },
                    landersAttachmentRemove : function($event){
                        if (!confirm('确定要删除此附件？')) return;
                        lister.item.remove($event);
                        Flat.set($scope, model_key, angular.toJson(lister.data()));
                    }
                })
            }
        }
    })
    .directive('landersNameValueInputer', function($compile, Flat, Dialog, List) {
        return {
            restrict : 'A',
            link : function($scope, $element, $attrs){
                var model_key = $attrs['nviModel'];
                var view_key = $attrs['nviView'];

                var html = '';
                html += '<div class="relative">';
                html += '   <a ng-click="landersNameValuesAdd($event)" class="btn btn-sm btn-primary absolute right-top"><i class="glyphicon glyphicon-plus"></i></a>';
                html += '</div>';
                html += '<ul class="hlist list">';
                html += '    <li ng-repeat="item in ' + view_key + '" class="mr20 mb5 list-item">';
                html += '        <span class="">{{item.name}}：{{item.value}}</span>';
                html += '        <a ng-click="landersNameValuesRemove($event)" class="btn btn-warning btn-xs ml5"><i class="glyphicon glyphicon-minus"></i></a>';
                html += '    </li>';
                html += '</ul>';
                html += '<input ng-model="' + model_key + '" type="hidden"/>';

                var el = $compile(html)($scope);
                $element.css({height:'100%'}).append(el);
                if (!$scope.$$phase) $scope.$apply();
                $element.find('.list').css({'margin-right':$element.find('.btn').width() + 20 })

                var lister = List.make($scope, view_key).data([]);
                $scope.$watch(model_key, function(model){
                    if (model) lister.data(model);
                });

                var html = '';
                html += '<form>';
                html += '   <table cellpadding="0" cellspacing="0" border="0" class="stereo form-table">';
                html += '   <tr>';
                html += '       <td class="w60"><label>名称</label></td>';
                html += '       <td><input ng-model="$runtime.nvi.name" maxlength="30" value="" type="text" class="text"/></td>';
                html += '   </tr>';
                html += '   <tr>';
                html += '       <td class="w60"><label>数据</label></td>';
                html += '       <td><textarea ng-model="$runtime.nvi.value" value="" type="text" class="text"></textarea></td>';
                html += '   </tr>';
                html += '   </table>';
                html += '</form>';
                angular.extend($scope, {
                    landersNameValuesAdd : function(){
                        Flat.set($scope, '$runtime.nvi', {});
                        setTimeout(function(){
                            Dialog.show($scope, {
                                title   : $attrs['nviName'],
                                content : html,
                                width   : 350,
                                lock    : true,
                                fixed   : true,
                                effect  : 'vmove1',
                                onload  : function(){
                                },
                                yes     : function(){
                                    var nvi = Flat.get($scope, '$runtime.nvi');
                                    lister.append(angular.extend({}, nvi));
                                    Flat.set($scope, model_key, angular.toJson(lister.data()));
                                },
                                no      : true
                            });
                        }, 200);
                    },
                    landersNameValuesRemove : function($event){
                        lister.item.remove($event);
                        Flat.set($scope, model_key, angular.toJson(lister.data()));
                    }
                })
            }
        }
    })
    .directive('landersUpload', function($rootScope, Flat) {
        return {
            restrict : 'A',
            link : function($scope, $element, $attrs) {
                Landers.loader.jsm(['landers.iframe', 'landers.upload,true'], function(){
                    var $form = $element.closest('form');
                    var rel = $element.attr('rel');
                    var $rel = $form.find('#' + rel);
                    var relModel = $rel.attr('ng-model');
                    $rel.val(Flat.get($scope, relModel) || '');

                    var relsmall = $element.attr('rel_small');
                    if (relsmall) {
                        var $relsmall = $form.find('#' + relsmall);
                        var relsmallModel = $relsmall.attr('ng-model');
                        $relsmall.val(Flat.get($scope, relsmallModel) || '');
                    }
                    var tipid = $element.attr('tipid');
                    var $tip = $form.find('#' + tipid);
                    var params = $element.attr('params');
                    if (params) params = angular.fromJson(params); else params = {};
                    $scope.$watch(
                        function(){return $rel.val()},
                        function(newValue){
                            Flat.set($scope, relModel, newValue);
                        }
                    );
                    if (relsmall && $relsmall.length && relsmallModel) {
                        $scope.$watch(
                            function(){return $relsmall.val()},
                            function(newValue){
                                Flat.set($scope, relsmallModel, newValue);
                            }
                        );
                    };
                    var opts = {scope:$scope};
                    if (relsmall && $relsmall.length) opts.$small = $relsmall;
                    if ($tip.length)  opts.$tip = $tip;
                    opts.faces = $element.attr('faces') || 0;

                    var pvw = $element.attr('pvw'), pvh = $element.attr('pvh');
                    if (pvw || pvh) {
                        opts.pvsize = {};
                        if (pvw) opts.pvsize.width = pvw;
                        if (pvh) opts.pvsize.height = pvh;
                    };
                    opts.onload = function(){
                        var upload = this;
                        if (params.init_logo) {
                            var $faces = upload.getfaces();
                            $faces.each(function(){
                                Upload.plug.attach_setlogo($(this), params.init_logo, 'val_small');
                            });
                        };
                    };
                    opts.onchange = function(){
                        if (!$scope.$$phase) $scope.$apply();
                    };
                    opts = $.extend({}, opts, params);
                    opts.hosturl = $rootScope.$settings.env.upload_host_url;
                    opts.debug = !!params.debug;
                    Landers.upload.create(
                        $element.attr('uploadid'),
                        params.apiurl || 'upload.php', $element, $rel, opts
                    );
                });
            }
        };
    })
